@@ -30,7 +30,7 @@ else:
     from skewx_projection import SkewXAxes
 
 # SkewT version
-__version__="1.0"
+__version__="1.0.1"
 
 class SkewXAxes(SkewXAxes):
     # In the SkewT package, SkewXAxes is a subclass of the one provided 
@@ -618,12 +618,16 @@ class Sounding(UserDict):
             P_el=eqlev[isstab][0]
             P_lfc=eqlev[isstab][0]
 
+        if isnan(P_lfc):
+            return P_lcl,P_lfc,P_el,0,0
+
         # need to handle case where dwpt is not available 
         # above a certain level for any reason. Most simplest 
         # thing to do is set it to a reasonably low value; 
         # this should be a conservative approach!
         dwpt=self.soundingdata['dwpt'].copy().soften_mask()
-        if dwpt[(pres>=P_el)*pres<P_lfc].mask.any():
+        # raise ValueError
+        if dwpt[(pres>=P_el).data*(pres<P_lfc).data].mask.any():
             print "WARNING: substituting dwpt.min() for masked values of DWPT in this sounding"
         dwpt[dwpt.mask]=dwpt.min()
         # dwptenv=interp(preswet,pres[::-1],dwpt[::-1])
@@ -631,41 +635,37 @@ class Sounding(UserDict):
         dwptenv=interp(pparcel,pres[::-1],dwpt[::-1])
 
         hght=self.soundingdata['hght']
-        if hght[pres>=P_el].mask.any():
+        if hght[(pres>=P_el).data].mask.any():
             raise NotImplementedError, "TODO: Implement standard atmosphere to substitute missing heights"
         # hghtenv=interp(preswet,pres[::-1],self.soundingdata['hght'][::-1])
         # NEW:
         hghtenv=interp(pparcel,pres[::-1],self.soundingdata['hght'][::-1])
 
-        if not isnan(P_lfc):
-            # Areas of POSITIVE Bouyancy
-            # cond1=(tempwet>=tempenv)*(preswet<=P_lfc)*(preswet>P_el)
-            # NEW:
-            cond1=(tparcel>=tempenv)*(pparcel<=P_lfc)*(pparcel>P_el)
-            # Areas of NEGATIVE Bouyancy
-            # cond2=(tempwet<tempenv)*(preswet<=P_lcl)*(preswet>P_el)
-            # NEW:
-            if totalcape:
-                cond2=(tparcel<tempenv)*(pparcel>P_el)
-            else:
-                cond2=(tparcel<tempenv)*(pparcel>P_lfc)
-            # Do CAPE calculation
-            # 1. Virtual temperature of parcel... remember it's saturated above LCL.
-            # e_parcel=SatVap(tempwet)
-            # Tv_parcel=VirtualTemp(tempwet+degCtoK,preswet*100.,e_parcel)
-            # e_env=SatVap(dwptenv)
-            # Tv_env=VirtualTemp(tempenv+degCtoK,preswet*100.,e_env)
-            # NEW:
-            e_parcel=SatVap(tparcel)
-            Tv_parcel=VirtualTemp(tparcel+degCtoK,pparcel*100.,e_parcel)
-            e_env=SatVap(dwptenv)
-            Tv_env=VirtualTemp(tempenv+degCtoK,pparcel*100.,e_env)
-
-            CAPE=trapz(9.81*(Tv_parcel[cond1]-Tv_env[cond1])/Tv_env[cond1],hghtenv[cond1])
-            CIN=trapz(9.81*(Tv_parcel[cond2]-Tv_env[cond2])/Tv_env[cond2],hghtenv[cond2])
+        # Areas of POSITIVE Bouyancy
+        # cond1=(tempwet>=tempenv)*(preswet<=P_lfc)*(preswet>P_el)
+        # NEW:
+        cond1=(tparcel>=tempenv)*(pparcel<=P_lfc)*(pparcel>P_el)
+        # Areas of NEGATIVE Bouyancy
+        # cond2=(tempwet<tempenv)*(preswet<=P_lcl)*(preswet>P_el)
+        # NEW:
+        if totalcape:
+            cond2=(tparcel<tempenv)*(pparcel>P_el)
         else:
-            CAPE=0
-            CIN=0
+            cond2=(tparcel<tempenv)*(pparcel>P_lfc)
+        # Do CAPE calculation
+        # 1. Virtual temperature of parcel... remember it's saturated above LCL.
+        # e_parcel=SatVap(tempwet)
+        # Tv_parcel=VirtualTemp(tempwet+degCtoK,preswet*100.,e_parcel)
+        # e_env=SatVap(dwptenv)
+        # Tv_env=VirtualTemp(tempenv+degCtoK,preswet*100.,e_env)
+        # NEW:
+        e_parcel=SatVap(tparcel)
+        Tv_parcel=VirtualTemp(tparcel+degCtoK,pparcel*100.,e_parcel)
+        e_env=SatVap(dwptenv)
+        Tv_env=VirtualTemp(tempenv+degCtoK,pparcel*100.,e_env)
+
+        CAPE=trapz(9.81*(Tv_parcel[cond1]-Tv_env[cond1])/Tv_env[cond1],hghtenv[cond1])
+        CIN=trapz(9.81*(Tv_parcel[cond2]-Tv_env[cond2])/Tv_env[cond2],hghtenv[cond2])
 
         return P_lcl,P_lfc,P_el,CAPE,CIN
 
